#
# spec file for package perl-Task-Weaken
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Task-Weaken
Version:        1.06
Release:        lp150.1.1
%define cpan_name Task-Weaken
Summary:        Ensure that a platform has weaken support
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Task-Weaken/
Source0:        https://cpan.metacpan.org/authors/id/E/ET/ETHER/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
One recurring problem in modules that use Scalar::Util's 'weaken' function
is that it is not present in the pure-perl variant.

While this isn't necessarily always a problem in a straight CPAN-based Perl
environment, some operating system distributions only include the pure-Perl
versions, don't include the XS version, and so weaken is then "missing"
from the platform, *despite* passing a dependency on Scalar::Util
successfully.

Most notably this is RedHat Linux at time of writing, but other come and go
and do the same thing, hence "recurring problem".

The normal solution is to manually write tests in each distribution to
ensure that 'weaken' is available.

This restores the functionality testing to a dependency you do once in your
_Makefile.PL_, rather than something you have to write extra tests for each
time you write a module.

It should also help make the package auto-generators for the various
operating systems play more nicely, because it introduces a dependency that
they *have* to have a proper weaken in order to work.

%prep
%setup -q -n %{cpan_name}-%{version}
# MANUAL BEGIN
sed -i -e 's/use inc::Module::Install/use lib q[.];\nuse inc::Module::Install/' Makefile.PL
# MANUAL END

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes CONTRIBUTING Makefile.footer Makefile.header README
%license LICENSE

%changelog
* Fri Apr 20 2018 coolo@suse.com
- updated to 1.06
  see /usr/share/doc/packages/perl-Task-Weaken/Changes
  1.06      2018-04-19 15:27:23Z
  - merge last commits from adamk's svn repository, which bump the
    minimum version of Scalar::Util in some cases (PR#1)
* Wed Feb  7 2018 coolo@suse.com
- updated to 1.05
  see /usr/share/doc/packages/perl-Task-Weaken/Changes
* Tue Oct  3 2017 coolo@suse.com
- patch the Makefile to build with perl 5.26
* Wed Dec 14 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Sun Aug 28 2011 andrea.turrini@gmail.com
- fixed typo in perl-Task-Weaken.spec
* Tue Mar  8 2011 jw@novell.com
- updated to 1.04:
  Updating author tests
  Updating to Module::Install
  Simple refactoring of Makefile.PL
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Sun Feb 21 2010 chris@computersalat.de
- cleanup spec
  o fix Url
  o modname > cpan_name
  o added perl-macros
  o added provides cpan_name
  o usage of more macros
  o added LICENSE to doc
* Sun Nov 15 2009 dmueller@suse.de
- update to 1.03:
  - Updating to flush out some old CPAN Testers results
* Tue Jul 15 2008 jw@suse.de
- initial check in version 1.02
